### Name: varSel
### Title: Variable selection using RSF
### Aliases: varSel
### Keywords: survival tree

### ** Examples

## Not run: 
##D #------------------------------------------------------------
##D # Minimal depth variable selection: pbc data with noise
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D vs <- varSel(Surv(days, status) ~ ., pbc)
##D 
##D # As dimension increases, mtry should increase
##D pbc.noise <- cbind(pbc, noise = matrix(rnorm(nrow(pbc) * 1000), nrow(pbc)))
##D vs.bigp <- varSel(Surv(days, status) ~ ., pbc.noise, mtry = 100)
##D 
##D #------------------------------------------------------------
##D # Variable hunting: van de Vijver microarray breast cancer
##D # Note: nrep is small for illustration; typical values are nrep = 100
##D 
##D data(vdv, package = "randomSurvivalForest")
##D vh <- varSel(Surv(Time, Censoring) ~ ., vdv, method = "vh", nrep = 10, nstep = 5)
##D 
##D # Same analysis, but using predefined weights for selecting a gene 
##D # for node splitting.  We illustrate this using univarate cox p-values.
##D 
##D if (library("survival", logical.return = TRUE) 
##D     & library("Hmisc", logical.return = TRUE))
##D {
##D   cox.weights <- function(rsf.f, rsf.data) {
##D     event.names <- all.vars(rsf.f)[1:2]
##D     p <- ncol(rsf.data) - 2
##D     event.pt <- match(event.names, names(rsf.data))
##D     predictor.pt <- setdiff(1:ncol(rsf.data), event.pt)
##D     sapply(1:p, function(j) {
##D       cox.out <- coxph(rsf.f, rsf.data[, c(event.pt, predictor.pt[j])])
##D       pvalue <- summary(cox.out)$coef[5]
##D       if (is.na(pvalue)) 1.0 else 1/(pvalue + 1e-100)
##D     })
##D   }       
##D 
##D   data(vdv, package = "randomSurvivalForest")
##D   rsf.f <- as.formula(Surv(Time, Censoring) ~ .)
##D   cox.wts <- cox.weights(rsf.f, vdv)
##D   vh.cox <- varSel(rsf.f, vdv, method = "vh", nstep = 5, predictorWt = cox.wts)
##D 
##D }
## End(Not run)


